summaryrefslogtreecommitdiffstats
path: root/include/comphelper/configuration.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/comphelper/configuration.hxx')
-rw-r--r--include/comphelper/configuration.hxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/include/comphelper/configuration.hxx b/include/comphelper/configuration.hxx
index 7c2a0a7fb4ec..de65a7ad3f1e 100644
--- a/include/comphelper/configuration.hxx
+++ b/include/comphelper/configuration.hxx
@@ -12,7 +12,7 @@
#include <sal/config.h>
-#include <o3tl/optional.hxx>
+#include <optional>
#include <com/sun/star/uno/Any.hxx>
#include <com/sun/star/uno/Reference.h>
#include <comphelper/comphelperdllapi.h>
@@ -158,18 +158,18 @@ private:
};
/// @internal
-template< typename T > struct Convert< o3tl::optional< T > >
+template< typename T > struct Convert< std::optional< T > >
{
- static css::uno::Any toAny(o3tl::optional< T > const & value) {
+ static css::uno::Any toAny(std::optional< T > const & value) {
return value
? css::uno::makeAny(*value)
: css::uno::Any();
}
- static o3tl::optional< T > fromAny(css::uno::Any const & value)
+ static std::optional< T > fromAny(css::uno::Any const & value)
{
return value.hasValue()
- ? o3tl::optional< T >(value.get< T >()) : o3tl::optional< T >();
+ ? std::optional< T >(value.get< T >()) : std::optional< T >();
}
private:
@@ -200,7 +200,7 @@ template< typename T, typename U > struct ConfigurationProperty
/// Get the value of the given (non-localized) configuration property.
///
/// For nillable properties, U is of type o3tl::optional<U'>.
static U get(
css::uno::Reference< css::uno::XComponentContext >
const & context = comphelper::getProcessComponentContext())
@@ -216,7 +216,7 @@ template< typename T, typename U > struct ConfigurationProperty
/// Set the value of the given (non-localized) configuration property, via a
/// given changes batch.
///
/// For nillable properties, U is of type o3tl::optional<U'>.
static void set(
U const & value,
std::shared_ptr< ConfigurationChanges > const & batch)
@@ -244,7 +244,7 @@ template< typename T, typename U > struct ConfigurationLocalizedProperty
/// locale currently set at the
/// com.sun.star.configuration.theDefaultProvider.
///
/// For nillable properties, U is of type o3tl::optional<U'>.
static U get(css::uno::Reference< css::uno::XComponentContext > const & context)
{
// Folding this into one statement causes a bogus error at least with
@@ -260,7 +260,7 @@ template< typename T, typename U > struct ConfigurationLocalizedProperty
/// com.sun.star.configuration.theDefaultProvider, via a given changes
/// batch.
///
/// For nillable properties, U is of type o3tl::optional<U'>.
static void set(
U const & value,
std::shared_ptr< ConfigurationChanges > const & batch)
@@ -200,7 +200,7 @@ template< typename T, typename U > struct ConfigurationProperty
/// Get the value of the given (non-localized) configuration property.
///
- /// For nillable properties, U is of type o3tl::optional<U'>.
+ /// For nillable properties, U is of type std::optional<U'>.
static U get(
css::uno::Reference< css::uno::XComponentContext >
@@ -216,7 +216,7 @@ template< typename T, typename U > struct ConfigurationProperty
/// given changes batch.
///
- /// For nillable properties, U is of type o3tl::optional<U'>.
+ /// For nillable properties, U is of type std::optional<U'>.
static void set(
U const & value,
@@ -244,7 +244,7 @@ template< typename T, typename U > struct ConfigurationLocalizedProperty
/// com.sun.star.configuration.theDefaultProvider.
///
- /// For nillable properties, U is of type o3tl::optional<U'>.
+ /// For nillable properties, U is of type std::optional<U'>.
static U get(css::uno::Reference< css::uno::XComponentContext > const & context)
{
@@ -260,7 +260,7 @@ template< typename T, typename U > struct ConfigurationLocalizedProperty
/// batch.
///
- /// For nillable properties, U is of type o3tl::optional<U'>.
+ /// For nillable properties, U is of type std::optional<U'>.
static void set(
U const & value,